@@ -20,6 +20,7 @@
 import os
 import re
 import sys
+from typing import Type
 
 from debian.changelog import (
     Changelog,
@@ -383,9 +384,10 @@ Arch: all
             applied, failed = run_lintian_fixers(
                 self.tree, [DummyFixer('dummy', 'some-tag')],
                 update_changelog=False)
+            revid = self.tree.last_revision()
         self.assertEqual(
                 [(FixerResult("Fixed some tag.\nExtended description.",
-                              ['some-tag'], 'certain'),
+                              ['some-tag'], 'certain', revision_id=revid),
                   'Fixed some tag.')],
                 applied)
         self.assertEqual({}, failed)
@@ -780,7 +782,7 @@ Patch-Name: aname
 
 class BaseScriptFixerTests(object):
 
-    script_fixer_cls = None
+    script_fixer_cls: Type[Fixer]
 
     def create_fixer(self, code):
         self.build_tree_contents([
